@@ -32,7 +32,8 @@ def plot_feature_importance(feature_importances, feature_names, title, \
     if feature_names is None:
         feature_names = range(feature_importances.size)
     plt.bar(feature_names, feature_importances, alpha=.8) # , width=2
-    if xtick_angle is None:
+    if xtick_angle is None or \
+        ( len(feature_names) > 100 and isinstance(feature_names[0], str) ): # to avoid crowdy strings
         plt.xticks([])
     else:
         plt.xticks(rotation = 90)
